"use client";

import { useState } from "react";
import { useSearchParams } from "next/navigation";
import SearchHeader from "@/components/search/SearchHeader";
import SearchFilters from "@/components/search/SearchFilters";
import SearchResults from "@/components/search/SearchResults";
import { useSchoolSearch } from "@/hooks/useSchoolSearch";

export default function SearchPage() {
  const searchParams = useSearchParams();
  const [isFiltersOpen, setIsFiltersOpen] = useState(false);
  const { 
    schools,
    isLoading,
    error,
    hasNextPage,
    fetchNextPage
  } = useSchoolSearch({
    query: searchParams.get("q") || "",
    filters: {
      location: searchParams.get("location") || "",
      type: searchParams.get("type") || "all",
      level: searchParams.get("level") || "all",
      rating: parseInt(searchParams.get("rating") || "0"),
    }
  });

  return (
    <div className="min-h-screen bg-background">
      <SearchHeader 
        onToggleFilters={() => setIsFiltersOpen(!isFiltersOpen)} 
      />
      <main className="container mx-auto px-4 py-8">
        <div className="grid lg:grid-cols-4 gap-8">
          <SearchFilters 
            className={`lg:block ${isFiltersOpen ? 'block' : 'hidden'}`}
          />
          <div className="lg:col-span-3">
            <SearchResults
              schools={schools}
              isLoading={isLoading}
              error={error}
              hasNextPage={hasNextPage}
              onLoadMore={fetchNextPage}
            />
          </div>
        </div>
      </main>
    </div>
  );
}